==> enchdesc-fabric-1.21.3-21.3.1-sources.jar: net/darkhax/enchdesc/common/impl/Config.java <==
package net.darkhax.enchdesc.common.impl;

import net.darkhax.pricklemc.common.api.annotations.Value;
import net.minecraft.class_124;
import net.minecraft.class_2561;
import net.minecraft.class_2583;

public class Config {

    @Value(comment = "Determines if the mod and its features are enabled.")
    public boolean enabled = true;

    @Value(comment = "When enabled, descriptions will only be displayed when looking at an enchanted book.")
    public boolean only_on_books = false;

    @Value(comment = "When enabled, descriptions will only be displayed when inside the enchanting table GUI.")
    public boolean only_in_enchanting_table = false;

    @Value(comment = "When enabled, descriptions will only be displayed when the user holds the shift key.")
    public boolean require_keybind = false;

    @Value(comment = "This text will be displayed when the require_keybind option is enabled and the user has not held the keybind.")
    public class_2561 activate_text = class_2561.method_43471("enchdesc.activate.message").method_27692(class_124.field_1063);

    @Value(comment = "Text that will be added to the start of each description. This can be used to add indents and other decorators.")
    public class_2561 prefix = class_2561.method_43473();

    @Value(comment = "Text that will be added to the end of each description.")
    public class_2561 suffix = class_2561.method_43473();

    @Value(comment = "The style of the description text. This controls the color, format, font, and other visual properties of the description.")
    public class_2583 style = class_2583.field_24360.method_10977(class_124.field_1063);
}

==> enchdesc-fabric-1.21.11-21.11.1-sources.jar: net/darkhax/enchdesc/common/impl/Config.java <==
package net.darkhax.enchdesc.common.impl;

import net.darkhax.pricklemc.common.api.annotations.Value;
import net.minecraft.class_124;
import net.minecraft.class_2561;
import net.minecraft.class_2583;

public class Config {

    @Value(comment = "Determines if the mod and its features are enabled.")
    public boolean enabled = true;

    @Value(comment = "When enabled, descriptions will only be displayed when looking at an enchanted book.")
    public boolean only_on_books = false;

    @Value(comment = "When enabled, descriptions will only be displayed when inside the enchanting table GUI.")
    public boolean only_in_enchanting_table = false;

    @Value(comment = "When enabled, descriptions will only be displayed when the user holds the shift key.")
    public boolean require_keybind = false;

    @Value(comment = "This text will be displayed when the require_keybind option is enabled and the user has not held the keybind.")
    public class_2561 activate_text = class_2561.method_43471("enchdesc.activate.message").method_27692(class_124.field_1063);

    @Value(comment = "Should the activate text be displayed?")
    public boolean display_activate_text = true;

    @Value(comment = "Text that will be added to the start of each description. This can be used to add indents and other decorators.")
    public class_2561 prefix = class_2561.method_43473();

    @Value(comment = "Text that will be added to the end of each description.")
    public class_2561 suffix = class_2561.method_43473();

    @Value(comment = "The style of the description text. This controls the color, format, font, and other visual properties of the description.")
    public class_2583 style = class_2583.field_24360.method_10977(class_124.field_1063);
}
